hotspot/src/share/vm/gc_implementation/g1/g1RemSet.inline.hpp
changeset 6250 5680f968c721
parent 6247 00e5cc407d03
child 6958 cfa71cf3564d
--- a/hotspot/src/share/vm/gc_implementation/g1/g1RemSet.inline.hpp	Wed Aug 04 13:03:23 2010 -0400
+++ b/hotspot/src/share/vm/gc_implementation/g1/g1RemSet.inline.hpp	Fri Aug 06 10:17:21 2010 -0700
@@ -62,13 +62,13 @@
   HeapRegion* to = _g1->heap_region_containing(obj);
   // The test below could be optimized by applying a bit op to to and from.
   if (to != NULL && from != NULL && from != to) {
     // The _par_traversal_in_progress flag is true during the collection pause,
     // false during the evacuation failure handing. This should avoid a
     // potential loop if we were to add the card containing 'p' to the DCQS
     // that's used to regenerate the remembered sets for the collection set,
     // in the event of an evacuation failure, here. The UpdateRSImmediate
     // closure will eventally call this routine.
-    if (_par_traversal_in_progress &&
+    if (_traversal_in_progress &&
         to->in_collection_set() && !self_forwarded(obj)) {
 
       assert(_cset_rs_update_cl[tid] != NULL, "should have been set already");
@@ -62,13 +62,13 @@
   // The test below could be optimized by applying a bit op to to and from.
   if (to != NULL && from != NULL && from != to) {
-    // The _par_traversal_in_progress flag is true during the collection pause,
-    // false during the evacuation failure handing. This should avoid a
+    // The _traversal_in_progress flag is true during the collection pause,
+    // false during the evacuation failure handling. This should avoid a
     // potential loop if we were to add the card containing 'p' to the DCQS
     // that's used to regenerate the remembered sets for the collection set,